from resultsFile import getFile
import argparse

def main():
    # read the command line arguments
    parser = argparse.ArgumentParser(description='Provide the QC file name to be checked')
    parser.add_argument('file', metavar='file', type=str, nargs='+',
                        help='a QC calculation file to be processed')

    args = parser.parse_args()

    num_files = len(args.file)


    print("__________________________________________________________")

    print("             Quantum Chemistry File Insights              ")

    print("__________________________________________________________")
    print("----------------------------------------------------------")


    for ind, f in enumerate(args.file):
        file = getFile(f)
        filetype = str(file).split('.')[-1].split()[0]


        print("File ", ind+1, " of ", num_files, "  :: ", f)
        print("File type        :: ", filetype)
        print("MO types         :: ", file.mo_types)

        print("----------------------------------------------------------")


if __name__ == "__main__":
    main()


from setuptools import setup

setup(
    name='qcinfo',
    version='0.1.0',
    description='A Python package for getting insights from quantum chemical calculation data.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Dr. Ravindra Shinde',
    author_email='r.l.shinde@utwente.nl',
    url='https://github.com/neelravi/qcinfo',
    packages=['qcinfo'],
    install_requires=["resultsFile"],
    entry_points={
        'console_scripts': [
            'qcinfo = qcinfo.cli:main',
        ],
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
)
